# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import enum

import winrt.system
from winrt import _winrt_windows_storage_pickers

__all__ = [
    "PickerLocationId",
    "PickerViewMode",
    "FileExtensionVector",
    "FileOpenPicker",
    "FilePickerFileTypesOrderedMap",
    "FilePickerSelectedFilesArray",
    "FileSavePicker",
    "FolderPicker",
]

class PickerLocationId(enum.IntEnum):
    DOCUMENTS_LIBRARY = 0
    COMPUTER_FOLDER = 1
    DESKTOP = 2
    DOWNLOADS = 3
    HOME_GROUP = 4
    MUSIC_LIBRARY = 5
    PICTURES_LIBRARY = 6
    VIDEOS_LIBRARY = 7
    OBJECTS3_D = 8
    UNSPECIFIED = 9

class PickerViewMode(enum.IntEnum):
    LIST = 0
    THUMBNAIL = 1

FileExtensionVector = _winrt_windows_storage_pickers.FileExtensionVector
winrt.system._mixin_mutable_sequence(FileExtensionVector)
FileOpenPicker = _winrt_windows_storage_pickers.FileOpenPicker
FilePickerFileTypesOrderedMap = _winrt_windows_storage_pickers.FilePickerFileTypesOrderedMap
winrt.system._mixin_mutable_mapping(FilePickerFileTypesOrderedMap)
FilePickerSelectedFilesArray = _winrt_windows_storage_pickers.FilePickerSelectedFilesArray
winrt.system._mixin_sequence(FilePickerSelectedFilesArray)
FileSavePicker = _winrt_windows_storage_pickers.FileSavePicker
FolderPicker = _winrt_windows_storage_pickers.FolderPicker
